@@ -19,11 +19,13 @@ cursesplus.transitions : Module for transitions
 
 """
 
-__version__ = "2.11.3"
+__version__ = "3.16.0"
 __author__ = "Enderbyte Programs"
 __package__ = "cursesplus"
 
 from .cp import *# Maintain backwards compatibility
 from . import transitions as transitions
 from . import filedialog as filedialog
-from . import messagebox as messagebox
\ No newline at end of file
+from . import messagebox as messagebox
+from . import utils as utils
+from .constants import *#Make colours readily available
\ No newline at end of file
