@@ -1,25 +1,20 @@
 import curses#Depends on windows-curses on win32
 from curses.textpad import rectangle
+import enum
 from . import messagebox
 import os
 from time import sleep
-from .transitions import _old as cursestransition
 import textwrap
+from .constants import *
+import datetime
+import copy
+from . import utils
 import threading
 
-#DEFINE SOME CONSTANTS
-BLACK = curses.COLOR_BLACK
-WHITE = curses.COLOR_WHITE
-RED = curses.COLOR_RED
-YELLOW = curses.COLOR_YELLOW
-GREEN = curses.COLOR_GREEN
-CYAN = curses.COLOR_CYAN
-BLUE = curses.COLOR_BLUE
-MAGENTA = curses.COLOR_MAGENTA
-
 _C_INIT = False
 
 class ArgumentError(Exception):
+    """You have provided an invalid combination of arguments"""
     def __init__(self, message, errors):            
         # Call the base class constructor with the parameters it needs
         super().__init__(message)
@@ -27,8 +22,7 @@ class ArgumentError(Exception):
         # Now for your custom code...
         self.errors = errors
 
-
-def displaymsg(stdscr,message: list):
+def displaymsg(stdscr,message: list,wait_for_keypress=True,show_heading_in_corder=False):
     """
     Display a message in a rectangle. Stdscr is the screen and message is a list. Each item in the list is a new line. For a single line message call displaymsg(stdscr,["message here"])
     Message will be dismissed when a key is pressed.
@@ -43,38 +37,19 @@ def displaymsg(stdscr,message: list):
     message = [m[0:x-5].split("\n")[0] for m in message]#Limiting characters
     maxs = max([len(s) for s in message])
     rectangle(stdscr,y//2-(len(message)//2)-1, x//2-(maxs//2)-1, y//2+(len(message)//2)+2, x//2+(maxs//2+1)+1)
-    stdscr.addstr(0,0,"Message: ")
-    mi = -(len(message)/2)
-    
-    for msgl in message:
-        mi += 1
-        stdscr.addstr(int(y//2+mi),int(x//2-len(msgl)//2),msgl)
-    stdscr.addstr(y-2,0,"Press any key to dismiss this message")
-    stdscr.refresh()
-    stdscr.getch()
-    
-
-def displaymsgnodelay(stdscr,message: list):
-    """
-    Display a message in a rectangle. message is a list. Each item in the list is a new line. Unlike displaymsg, the message will not need a keypress to continue. This is good for progress waiing.
-    """
-    stdscr.clear()
-    x,y = os.get_terminal_size()
-    ox = 0
-    for o in message:
-        ox += 1
-        if "\n" in o:
-            message.insert(ox,o.split("\n")[1])
-    message = [m[0:x-5].split("\n")[0] for m in message]#Limiting characters
-    maxs = max([len(s) for s in message])
-    rectangle(stdscr,y//2-(len(message)//2)-1, x//2-(maxs//2)-1, y//2+(len(message)//2)+2, x//2+(maxs//2+1)+1)
-    stdscr.addstr(0,0,"Message: ")
+    if show_heading_in_corder:
+        stdscr.addstr(0,0,"Message: ")
     mi = -(len(message)/2)
     
     for msgl in message:
         mi += 1
         stdscr.addstr(int(y//2+mi),int(x//2-len(msgl)//2),msgl)
     stdscr.refresh()
+    if wait_for_keypress:
+        stdscr.addstr(y-2,0,"Press any key to dismiss this message")
+        stdscr.refresh()
+        stdscr.getch()
+    
 def __retr_nbl_lst(input:list)->list:
     return [l for l in input if str(l) != ""]  
 def __calc_nbl_list(input:list)->int:
@@ -90,29 +65,29 @@ def str_contains_word(s:str,string:str) -> bool:
 def list_get_maxlen(l:list) -> int:
     return max([len(s) for s in l])
 
-def coloured_option_menu(stdscr,options:list[str],title="Please choose an option from the list below",colouring=[["back",RED]]) -> int:
+def coloured_option_menu(stdscr,options:list[str],title="Please choose an option from the list below",colouring=[["back",RED]],footer="",preselected=0) -> int:
     """An alternate optionmenu that has colours"""
-    selected = 0
+    selected = preselected
     offset = 0
     maxl = list_get_maxlen(options)
     while True:
         stdscr.clear()
         mx,my = os.get_terminal_size()
         
-        filline(stdscr,0,set_colour(BLUE,WHITE))
-        filline(stdscr,1,set_colour(WHITE,BLACK))
+        utils.fill_line(stdscr,0,set_colour(BLUE,WHITE))
+        utils.fill_line(stdscr,1,set_colour(WHITE,BLACK))
         stdscr.addstr(0,0,title,set_colour(BLUE,WHITE))
         stdscr.addstr(1,0,"Use the up and down arrow keys to navigate and enter to select",set_colour(WHITE,BLACK))
         oi = 0
         for op in options[offset:offset+my-7]:
             col = WHITE
             for colour in colouring:
-                if str_contains_word(op,colour[0]):
+                if str_contains_word(op.lower(),colour[0].lower()):
                     col = colour[1]
             if not oi == selected-offset:
-                stdscr.addstr(oi+3,7,op,set_colour(BLACK,col))
+                stdscr.addstr(oi+3,7,op[0:mx-10],set_colour(BLACK,col))
             else:
-                stdscr.addstr(oi+3,7,op,set_colour(BLACK,col) | curses.A_UNDERLINE | curses.A_BOLD)
+                stdscr.addstr(oi+3,7,op[0:mx-10],set_colour(BLACK,col) | curses.A_UNDERLINE | curses.A_BOLD)
             oi += 1
         stdscr.addstr(selected+3-offset,1,"-->")
         stdscr.addstr(selected+3-offset,maxl+9,"<--")
@@ -121,6 +96,7 @@ def coloured_option_menu(stdscr,options:list[str],title="Please choose an option
             stdscr.addstr(3,maxl+15,f"{offset} options above")
         if len(options) > offset+my-8:
             stdscr.addstr(oi+2,maxl+15,f"{len(options)-offset-my+8} options below")
+        stdscr.addstr(oi+4,0,footer)
         stdscr.refresh()
         ch = stdscr.getch()
         if ch == curses.KEY_DOWN and selected < len(options)-1:
@@ -135,6 +111,32 @@ def coloured_option_menu(stdscr,options:list[str],title="Please choose an option
                 offset -= 1
         elif ch == 10 or ch == 13 or ch == curses.KEY_ENTER:
             return selected
+        elif ch == curses.KEY_HOME:
+            selected = 0
+            offset = 0
+        elif ch == curses.KEY_END:
+            selected = len(options)-1
+            if selected > my-8+offset:
+                offset = selected-my+8
+
+class SearchMethods(enum.Enum):
+    Contains = 1
+    FullWord = 2
+    ContainsCaseDep = 3
+    FullWordCaseDep = 6
+
+def dynamic_search_and_select(stdscr,items:list[str],prompt:str,allowcancel=True):
+    """Dynamic searching. Returns index. NOTE! NOT YET FINISHED!"""
+    searchindex:list[str] = []
+    searchoffset = 0
+    searchcursor = 0
+    selected = 0
+    ywriteoffset = 4
+    if allowcancel:
+        ywriteoffset += 1
+    while True:
+        utils.fill_line(stdscr,0,set_colour(BLUE,WHITE))
+        stdscr.addstr(0,0,prompt,set_colour(BLUE,WHITE))      
 
 def cursesinput(stdscr,prompt: str,lines=1,maxlen=0,passwordchar:str=None,retremptylines=False,prefiltext="",bannedcharacters="") -> str:
     """
@@ -163,7 +165,7 @@ def cursesinput(stdscr,prompt: str,lines=1,maxlen=0,passwordchar:str=None,retrem
     col=0
     xoffset = 0
     while True:
-        filline(stdscr,0,set_colour(WHITE,BLACK))
+        utils.fill_line(stdscr,0,set_colour(WHITE,BLACK))
         stdscr.addstr(0,0,str(prompt+[" (Press ctrl-D to submit)" if lines != 1 else " (Press enter to submit)"][0])[0:mx-2],set_colour(WHITE,BLACK))
         rectangle(stdscr,1,0,lnrectmaxy,mx-1)
         chi = 1
@@ -287,32 +289,45 @@ def cursesinput(stdscr,prompt: str,lines=1,maxlen=0,passwordchar:str=None,retrem
                             xoffset += 1
                             stdscr.clear()
     
+class CheckBoxItem:
+    def __init__(self,dict_name,display_name,defaultvalue=False):
+        self.dn = dict_name
+        self.display = display_name
+        self.dv = defaultvalue
+    def get_dict_display(self):
+        return {self.display:self.dv}
+    def get_dict_internal(self):
+        return {self.dn:self.dv}
+
 def checkboxlist(stdscr,options,message="Please choose options from the list below",minimumchecked=0,maximumchecked=1000) -> dict:
-    """A list of checkboxes for multiselect. Options may be a list like ["Option1","Option2"]. In this case, values will be defaultd to False (unchecked.) Alternatively you can supply a dict like {"Option1":True,"Option1":False}. In that case, some options will be pre-checked. This returns a dict in the same style as the input."""
+    """A list of checkboxes for multiselect. Options may be a list like ["Option1","Option2"]. In this case, values will be defaultd to False (unchecked.) Alternatively you can supply a dict like {"Option1":True,"Option1":False}. In that case, some options will be pre-checked.
+     **NEW IN 2.11.6** - Provide CheckBoxItems to seperate internal and display
+       This returns a dict in the same style as the input."""
     offset = 0
     selected = 0
     if type(options) == list:
-        options = {k:False for k in options}
+        if type(options[0]) == str:
+            options = [CheckBoxItem(o,o,False) for o in options]
     elif type(options) == dict:
-        pass
+        options = [CheckBoxItem(k,k,v) for k,v in options.items()]
     else:
         raise TypeError("Please provide a list or dict.")
-    maxl = list_get_maxlen(list(options.keys()))
+    maxl = list_get_maxlen([__x.display for __x in options])
     while True:
         my,mx = stdscr.getmaxyx()
         stdscr.clear()
-        filline(stdscr,0,set_colour(BLUE,WHITE))
-        filline(stdscr,1,set_colour(WHITE,BLACK))
-        filline(stdscr,my-1,set_colour(WHITE,BLACK))
+        utils.fill_line(stdscr,0,set_colour(BLUE,WHITE))
+        utils.fill_line(stdscr,1,set_colour(WHITE,BLACK))
+        utils.fill_line(stdscr,my-1,set_colour(WHITE,BLACK))
         stdscr.addstr(0,0,message,set_colour(BLUE,WHITE))
         stdscr.addstr(1,0,"Use the up and down arrow keys to navigate, use space to select.",set_colour(WHITE,BLACK))
         stdscr.addstr(my-1,0,"Press D when you are done",set_colour(WHITE,BLACK))
         ci = 3
-        for choice in list(options.items())[offset:offset+my-6]:
+        for choice in options[offset:offset+my-6]:
             #choice = list(choice)
-            stdscr.addstr(ci,0,choice[0])
+            stdscr.addstr(ci,0,choice.display)
             stdscr.addstr(ci,maxl+2,"[ ]")
-            if choice[1]:
+            if choice.dv:
                 stdscr.addstr(ci,maxl+3,"*")
             ci += 1
         stdscr.addstr(selected-offset+3,maxl+8,"<--")
@@ -329,18 +344,18 @@ def checkboxlist(stdscr,options,message="Please choose options from the list bel
             if selected < offset:
                 offset -= 1
         elif ch == 10 or ch == 13 or ch == curses.KEY_ENTER or ch == 32:
-            options[list(options.keys())[selected]] = not options[list(options.keys())[selected]]
+            options[selected].dv = not options[selected].dv
             #messagebox.showinfo(stdscr,[str(options)])
         elif ch == 100:
-            if len([t for t in list(options.values()) if t]) <= maximumchecked and len([t for t in list(options.values()) if t]) >= minimumchecked:
-                return options
+            if len([t for t in options if t.dv]) <= maximumchecked and len([t for t in options if t.dv]) >= minimumchecked:
+                return { o.dn:o.dv for o in options}
             else:
                 messagebox.showerror(stdscr,[f"You must choose between {minimumchecked} and {maximumchecked} options."])
 
-def displayops(stdscr,options: list,title="Please choose an option") -> int:
+def optionmenu(stdscr,options: list,title="Please choose an option",preselected=0) -> int:
     """Display an options menu provided by options list. ALso displays title. Returns integer value of selected item."""
     mx, my = os.get_terminal_size()
-    selected = 0
+    selected = preselected
     stdscr.clear()
     options = [l[0:mx-3] for l in options]
     maxlen = max([len(l) for l in options])
@@ -380,21 +395,10 @@ def displayops(stdscr,options: list,title="Please choose an option") -> int:
             selected += 1
         elif _ch == curses.KEY_BACKSPACE or _ch == 98:
             return -1
-        stdscr.erase()
-       
-def optionmenu(stdscr,options:list,title="Please choose an option and press enter") -> int:
-    """Alias function to displayops()"""
-    return displayops(stdscr,options,title)
-
-def askyesno_old(stdscr,title: str) -> bool:
-    """Ask a yes no question provided by title."""
-    result = displayops(stdscr,["Yes","No"],title)
-    if result == 0:
-        return True
-    else:
-        return False
+        
 _AVAILABLE_COL = list(range(1,255,1))
 _COL_INDEX = {}
+
 def set_colour(background: int, foreground: int) -> int:
     global _C_INIT
     global _COL_INDEX
@@ -413,33 +417,15 @@ def set_colour(background: int, foreground: int) -> int:
         raise Warning("Out of colours!")
         _AVAILABLE_COL = list(range(1,255,1))#Replenish list
     i = _AVAILABLE_COL.pop(0)
-    curses.init_pair(i,foreground,background)
+    try:
+        curses.init_pair(i,foreground,background)
+    except:
+        return curses.color_pair(list(list(_COL_INDEX.keys())[0].keys())[0])#Fix massive problem on windows. However, this has the side effect of causing buginess, but this is better than a crash
     if not str(foreground) in _COL_INDEX.keys():
         _COL_INDEX[str(foreground)] = {}
     _COL_INDEX[str(foreground)][str(background)] = i
     return curses.color_pair(i)
 
-def set_color(background: int,foreground: int) -> int:
-    return set_colour(background,foreground)
-
-def displayerror(stdscr,e,msg: str):
-    """
-    Display an error message
-    """
-    displaymsg(stdscr,["An error occured",msg,str(e)])
-
-def filline(stdscr,line: int,colour: int):
-    """Fill a line, colour is the result of set_colour(fg,bg)"""
-    stdscr.addstr(line,0," "*(os.get_terminal_size()[0]-1),colour)
-
-def hidecursor():
-    """Hide Cursor. Can only be called in an active curses window"""
-    curses.curs_set(0)
-
-def showcursor():
-    """Show cursor. Can only be called in an active curses window"""
-    curses.curs_set(1)
-
 def numericinput(stdscr,message="Please input a number",allowdecimals=False,allownegatives=False,minimum=None,maximum=None,prefillnumber=None) -> float:
     if prefillnumber is not None:
         prl = str(prefillnumber)
@@ -517,11 +503,11 @@ def textview(stdscr,file=None,text=None,isagreement=False,requireyes=True,messag
                 broken_text += [""]
             else:
                 broken_text += textwrap.wrap(text,n)
-        filline(stdscr,0,set_colour(WHITE,BLACK))
+        utils.fill_line(stdscr,0,set_colour(WHITE,BLACK))
         stdscr.addstr(0,0,message[0:mx-8],set_colour(WHITE,BLACK))
         prog = f"{offset}/{len(broken_text)}"
         stdscr.addstr(0,mx-len(prog)-1,prog,set_colour(WHITE,BLACK))
-        filline(stdscr,my-1,set_colour(WHITE,BLACK))
+        utils.fill_line(stdscr,my-1,set_colour(WHITE,BLACK))
         if isagreement:
             stdscr.addstr(my-1,0,"A: Agree | D: Disagree",set_colour(WHITE,BLACK))
         else:
@@ -592,16 +578,16 @@ class PleaseWaitScreen:
     def destroy(self):
         del self
 
-class ProgressBarTypes:
-    FullScreenProgressBar: int = 0
-    SmallProgressBar: int = 1
-class ProgressBarLocations:
+class ProgressBarTypes(enum.Enum):
+    FullScreenProgressBar = 0
+    SmallProgressBar = 1
+class ProgressBarLocations(enum.Enum):
     TOP = 0
     CENTER = 1
     BOTTOM = 2
 
 class ProgressBar:
-    def __init__(self,stdscr,max_value: int, bar_type=ProgressBarTypes.SmallProgressBar,bar_location=ProgressBarLocations.TOP,step_value=1,x_size=None,show_percent=True,show_log=None,message="Progress",waitforkeypress=False):
+    def __init__(self,stdscr,max_value: int, bar_type=ProgressBarTypes.SmallProgressBar,bar_location=ProgressBarLocations.TOP,step_value=1,show_percent=True,show_log=None,message="Progress",waitforkeypress=False):
         """Display a Progress Bar with a log. Good for install progresses"""
         self.screen = stdscr
         if show_log is not None:
@@ -627,11 +613,11 @@ class ProgressBar:
         self.wfkp = waitforkeypress
     def update(self):
         sz = self.screen.getmaxyx()[0]
-        if self.barloc == 0:
+        if self.barloc == ProgressBarLocations.TOP:
             ydraw = 0
-        elif self.barloc == 1:
+        elif self.barloc == ProgressBarLocations.CENTER:
             ydraw = sz //2-1
-        elif self.barloc == 2:
+        elif self.barloc == ProgressBarLocations.BOTTOM:
             ydraw = sz-4
         lheight = self.my - 7
         """Redraws progress bar"""
@@ -639,16 +625,16 @@ class ProgressBar:
             self.screen.erase()
         self.screen.addstr(ydraw,0," "*(self.mx-1),set_colour(BLUE,WHITE))
         self.screen.addstr(ydraw,0,self.msg[0:self.mx-1],set_colour(BLUE,WHITE))
-        #filline(self.screen,1,set_colour(GREEN,WHITE))
-        filline(self.screen,ydraw+2,set_colour(RED,WHITE))
-        #filline(self.screen,3,set_colour(GREEN,WHITE))
+        #utils.fill_line(self.screen,1,set_colour(GREEN,WHITE))
+        utils.fill_line(self.screen,ydraw+2,set_colour(RED,WHITE))
+        #utils.fill_line(self.screen,3,set_colour(GREEN,WHITE))
         self.screen.addstr(ydraw+1,0,"-"*(self.mx-1),set_colour(RED,WHITE))
         self.screen.addstr(ydraw+3,0,"-"*(self.mx-1),set_colour(RED,WHITE))
         barfill = round((self.value/self.max)*self.mx-1)
         if not self.value > self.max:
             self.screen.addstr(ydraw+2,0," "*barfill,set_colour(GREEN,WHITE))
         else:
-            self.screen.addstr(ydraw+2,0," "*self.mx-1,set_colour(GREEN,WHITE))
+            self.screen.addstr(ydraw+2,0," "*(self.mx-1),set_colour(GREEN,WHITE))
         self.screen.addstr(ydraw+3,0,self.submsg[0:self.mx-1],set_colour(RED,WHITE))
         if self.sp:
             self.screen.addstr(ydraw+3,self.mx-7,f"{round(self.value/self.max*100,1)} %",set_colour(RED,WHITE))
@@ -684,4 +670,115 @@ class ProgressBar:
         """Add text to log with colour colour"""
         self.loglist.append(text)
         self.lclist.append(colour)
-        self.update() 
\ No newline at end of file
+        self.update() 
+
+class DateTimeSelectorTypes(enum.Enum):
+    DATEONLY = 0
+    TIMEONLY = 1
+    DATEANDTIME = 2
+
+def _dt_str_proc(stype,dx: datetime.date,tx:datetime.time) -> str:
+    if stype == DateTimeSelectorTypes.DATEONLY:
+        return dx.strftime("%Y-%m-%d")
+    elif stype == DateTimeSelectorTypes.TIMEONLY:
+        return tx.strftime("%H:%M:%S")
+    elif stype == DateTimeSelectorTypes.DATEANDTIME:
+        return dx.strftime("%Y-%m-%d") + " " + tx.strftime("%H:%M:%S")
+
+def date_time_selector(stdscr,stype:DateTimeSelectorTypes,prompt:str,allow_past = True,allow_future = True,starting_time=datetime.datetime.now().replace(microsecond=0)):
+    """Select a date and time. This will return a Time, Date, or DateTime depending on the type
+    Note- For the starting date, you should delete microseconds otherwise you will get weird results"""
+    if not allow_future and not allow_past:
+        raise ArgumentError("You may not forbid both the past and the future")
+    if stype == DateTimeSelectorTypes.DATEANDTIME:
+        dx = starting_time.date()
+        tx = starting_time.time()
+    elif stype == DateTimeSelectorTypes.DATEONLY:
+        dx = starting_time.date()
+        tx = None
+    elif stype == DateTimeSelectorTypes.TIMEONLY:
+        dx = None
+        tx = starting_time.time()
+    while True:
+        dnt = datetime.datetime.now()
+        nlval = _dt_str_proc(stype,dx,tx)
+        if dx is None:
+            opts = ["Finish","Set Hour","Set Minute","Set Second"]
+        elif tx is None:
+            opts = ["Finish","Set Year","Set Month","Set Day"]
+        else:
+            opts = ["Finish","Set Year","Set Month","Set Day","Set Hour","Set Minute","Set Second"]
+        chosen = coloured_option_menu(stdscr,opts,f"SELECTED {nlval} | {prompt}",[["finish",GREEN]],"Choose options below to set the date/time")
+        if chosen == 0:
+            if dx is None:
+                return tx
+            elif tx is None:
+                return dx
+            else:
+                return datetime.datetime.combine(dx,tx)
+        if "Year" in opts[chosen]:
+            tmp = copy.deepcopy(dx)
+            tmp = tmp.replace(year = int(numericinput(stdscr,"Please input a new year value",False,False,1970)))
+            if not allow_past and tmp < dnt.date():
+                messagebox.showerror(stdscr,["Dates in the past are not allowed"])
+            elif not allow_future and tmp > dnt.date():
+                messagebox.showerror(stdscr,["Dates in the future are not allowed"])
+            else:
+                dx = copy.deepcopy(tmp)#If no errors, commit tmp back to dx
+        elif "Month" in opts[chosen]:
+            tmp = copy.deepcopy(dx)
+            tmp = tmp.replace(month = optionmenu(stdscr,["January","February","March","April","May","June","July","August","September","October","November","December"],"Please choose a new month")+1)
+            if not allow_past and tmp < dnt.date():
+                messagebox.showerror(stdscr,["Dates in the past are not allowed"])
+            elif not allow_future and tmp > dnt.date():
+                messagebox.showerror(stdscr,["Dates in the future are not allowed"])
+            else:
+                dx = copy.deepcopy(tmp)#If no errors, commit tmp back to dx
+        elif "Day" in opts[chosen]:
+            try:
+                tmp = copy.deepcopy(dx)
+                tmp = tmp.replace(day = int(numericinput(stdscr,"Please input a new day value",False,False,1,31)))
+                if not allow_past and tmp < dnt.date():
+                    messagebox.showerror(stdscr,["Dates in the past are not allowed"])
+                elif not allow_future and tmp > dnt.date():
+                    messagebox.showerror(stdscr,["Dates in the future are not allowed"])
+                else:
+                    dx = copy.deepcopy(tmp)#If no errors, commit tmp back to dx
+            except:
+                messagebox.showerror(stdscr,["That is an invalid value"])
+        elif "Hour" in opts[chosen]:
+            try:
+                tmp = copy.deepcopy(tx)
+                tmp = tmp.replace(hour = int(numericinput(stdscr,"Please input a new hour value",False,False,0,24)))
+                if not allow_past and tmp < dnt.time():
+                    messagebox.showerror(stdscr,["Dates in the past are not allowed"])
+                elif not allow_future and tmp > dnt.time():
+                    messagebox.showerror(stdscr,["Dates in the future are not allowed"])
+                else:
+                    tx = copy.deepcopy(tmp)#If no errors, commit tmp back to dx
+            except:
+                messagebox.showerror(stdscr,["That is an invalid value"])
+        elif "Minute" in opts[chosen]:
+            try:
+                tmp = copy.deepcopy(tx)
+                tmp = tmp.replace(minute = int(numericinput(stdscr,"Please input a new minute value",False,False,0,60)))
+                if not allow_past and tmp < dnt.time():
+                    messagebox.showerror(stdscr,["Dates in the past are not allowed"])
+                elif not allow_future and tmp > dnt.time():
+                    messagebox.showerror(stdscr,["Dates in the future are not allowed"])
+                else:
+                    tx = copy.deepcopy(tmp)#If no errors, commit tmp back to dx
+            except:
+                messagebox.showerror(stdscr,["That is an invalid value"])
+        elif "Second" in opts[chosen]:
+            try:
+                tmp = copy.deepcopy(tx)
+                tmp = tmp.replace(second = int(numericinput(stdscr,"Please input a new second value",False,False,0,60)))
+                if not allow_past and tmp < dnt.time():
+                    messagebox.showerror(stdscr,["Dates in the past are not allowed"])
+                elif not allow_future and tmp > dnt.time():
+                    messagebox.showerror(stdscr,["Dates in the future are not allowed"])
+                else:
+                    tx = copy.deepcopy(tmp)#If no errors, commit tmp back to dx
+            except:
+                messagebox.showerror(stdscr,["That is an invalid value"])
\ No newline at end of file
