@@ -2,10 +2,18 @@ from . import cp
 import os
 from curses.textpad import rectangle
 import curses
+import enum
 
-def askyesno(stdscr,message: list = [],colour=False) -> bool:
+class MessageBoxStates(enum.Enum):
+    OK = 1
+    CANCEL = 0
+    YES = 1
+    NO = 0
+    RETRY = 1
+
+def askyesno(stdscr,message: list = [],colour=False,default=MessageBoxStates.YES) -> bool:
     """Display a messagebox that asks a user a questions. Returns TRUE on Yes and FALSE on No. Colour is green"""
-    selected = True
+    selected = default == MessageBoxStates.YES
     x,y = os.get_terminal_size()
     ox = 0
     if colour:
@@ -41,9 +49,9 @@ def askyesno(stdscr,message: list = [],colour=False) -> bool:
         elif ch == 10 or ch == 13 or ch == curses.KEY_ENTER:
             return selected
 
-def askokcancel(stdscr,message: list = [],colour=False) -> bool:
+def askokcancel(stdscr,message: list = [],colour=False,default=MessageBoxStates.OK) -> bool:
     """Display a messagebox that asks a user a question OK or canel  Returns TRUE on OK and FALSE on Cancel. Colour is green"""
-    selected = True
+    selected = default == MessageBoxStates.OK
     x,y = os.get_terminal_size()
     ox = 0
     if colour:
@@ -76,9 +84,9 @@ def askokcancel(stdscr,message: list = [],colour=False) -> bool:
         elif ch == 10 or ch == 13 or ch == curses.KEY_ENTER:
             return selected
         
-def askretrycancel(stdscr,message: list = [],colour=False) -> bool:
+def askretrycancel(stdscr,message: list = [],colour=False,default=MessageBoxStates.RETRY) -> bool:
     """Display a messagebox that asks a user a question OK or canel  Returns TRUE on OK and FALSE on Cancel. Colour is green"""
-    selected = True
+    selected = default == MessageBoxStates.RETRY
     x,y = os.get_terminal_size()
     ox = 0
     if colour:
@@ -132,7 +140,7 @@ def showinfo(stdscr,message: list = [],title:str="Info",colour=False) -> None:
             for bx in range(x//2-(maxs//2)-1,x//2+(maxs//2+1)+1):
                 stdscr.addstr(by,bx," ",cp.set_colour(BGCL,cp.WHITE))
         rectangle(stdscr,y//2-(len(message)//2)-1, x//2-(maxs//2)-1, y//2+(len(message)//2)+4, x//2+(maxs//2+1)+1)
-        stdscr.addstr(y//2-(len(message)//2)-1, x//2-(maxs//2)-1,title)
+        stdscr.addstr(y//2-(len(message)//2)-1, x//2-(maxs//2),"┤"+title+"├")
         mi = -(len(message)/2)
         stdscr.addstr(y//2+(len(message)//2)+3,x//2-(maxs//2),"[OK]",cp.set_colour(cp.WHITE,cp.BLACK)) 
         for msgl in message:
@@ -165,7 +173,7 @@ def showwarning(stdscr,message: list = [],title:str="Warning",colour=False) -> N
             for bx in range(x//2-(maxs//2)-1,x//2+(maxs//2+1)+1):
                 stdscr.addstr(by,bx," ",cp.set_colour(BGCL,cp.WHITE))
         rectangle(stdscr,y//2-(len(message)//2)-1, x//2-(maxs//2)-1, y//2+(len(message)//2)+4, x//2+(maxs//2+1)+1)
-        stdscr.addstr(y//2-(len(message)//2)-1, x//2-(maxs//2)-1,title)
+        stdscr.addstr(y//2-(len(message)//2)-1, x//2-(maxs//2),"┤"+title+"├")
         mi = -(len(message)/2)
         stdscr.addstr(y//2+(len(message)//2)+3,x//2-(maxs//2),"[OK]",cp.set_colour(cp.WHITE,cp.BLACK)) 
         for msgl in message:
@@ -198,7 +206,7 @@ def showerror(stdscr,message: list = [],title:str="Error",colour=False) -> None:
             for bx in range(x//2-(maxs//2)-1,x//2+(maxs//2+1)+1):
                 stdscr.addstr(by,bx," ",cp.set_colour(BGCL,cp.WHITE))
         rectangle(stdscr,y//2-(len(message)//2)-1, x//2-(maxs//2)-1, y//2+(len(message)//2)+4, x//2+(maxs//2+1)+1)
-        stdscr.addstr(y//2-(len(message)//2)-1, x//2-(maxs//2)-1,title)
+        stdscr.addstr(y//2-(len(message)//2)-1, x//2-(maxs//2),"┤"+title+"├")
         mi = -(len(message)/2)
         stdscr.addstr(y//2+(len(message)//2)+3,x//2-(maxs//2),"[OK]",cp.set_colour(cp.WHITE,cp.BLACK)) 
         for msgl in message:
